==> v1.2.5.tar.gz: bonzo-timer_1.8.9/src/main/java/xyz/stachel/bonzotimer/ChatHandler.java <==
package xyz.stachel.bonzotimer;

import net.minecraft.client.Minecraft;
import net.minecraft.event.ClickEvent;
import net.minecraft.util.ChatComponentText;
import net.minecraft.util.ChatStyle;
import net.minecraft.util.EnumChatFormatting;
import net.minecraftforge.client.event.ClientChatReceivedEvent;
import net.minecraftforge.fml.common.eventhandler.SubscribeEvent;
import org.jetbrains.annotations.NotNull;
import net.minecraftforge.fml.common.gameevent.TickEvent;

import java.util.regex.Matcher;
import java.util.regex.Pattern;

public class ChatHandler {
  private static final Pattern PARTY_PATTERN = Pattern.compile("Party > (?:(?:\\[VIP\\+?]|\\[MVP\\+?\\+?]) )?([a-zA-Z0-9_]{2,16}): (.*)");
  private static final Pattern TRANSFER_PATTERN = Pattern.compile("The party was transferred to (?:\\[(?:VIP\\+?|MVP\\+{0,2}|YOUTUBE|MOD|ADMIN)\\] )?([a-zA-Z0-9_]{2,16}) by (?:\\[(?:VIP\\+?|MVP\\+{0,2}|YOUTUBE|MOD|ADMIN)\\] )?([a-zA-Z0-9_]{2,16})");
  private static final Pattern PROMOTE_PATTERN = Pattern.compile("(?:\\[(?:VIP\\+?|MVP\\+{0,2}|YOUTUBE|MOD|ADMIN)\\])?([a-zA-Z0-9_]{2,16}) has promoted (?:\\[(?:VIP\\+?|MVP\\+{0,2}|YOUTUBE|MOD|ADMIN)\\] )?([a-zA-Z0-9_]{2,16}) to Party Leader");
  private static final String[] COLOR_MAPPING = { "§6ORANGE", "§aGREEN", "§4RED" ,"§9BLUE", "§5PRPLX" };
  private int transferCountdown = 0;
  private boolean autotransferEnabled = false;
  private int colorChangeCooldown = 0;
  private int color = 0;
  private String oldLeader = null;

  public void setTransferEnabled(boolean b) {
    this.autotransferEnabled = b;
  }

  @SubscribeEvent
  public void onTick(TickEvent.@NotNull ClientTickEvent event) {
    if (colorChangeCooldown > 0) {
      colorChangeCooldown--;
    } else {
      color = 0;
    }
    if (transferCountdown > 1) {
      transferCountdown--;
    } else if (transferCountdown == 1 && Minecraft.getMinecraft().thePlayer != null && this.oldLeader != null) {
      transferCountdown--;
      Minecraft.getMinecraft().thePlayer.sendChatMessage("/p transfer " + this.oldLeader);
    }
  }

  @SubscribeEvent
  public void onChatReceived(@NotNull ClientChatReceivedEvent event) {
    if (event.type == 2) return;
      final String strippedMessage = event.message.getUnformattedText().replaceAll("§[0-9a-fklmnor]", "").trim();

    if (autotransferEnabled) {
      final Matcher transfer = TRANSFER_PATTERN.matcher(strippedMessage);
      final Matcher promote = PROMOTE_PATTERN.matcher(strippedMessage);
      String newLeader = "";
      if (transfer.matches()) {
        this.oldLeader = transfer.group(2);
        newLeader = transfer.group(1);
      } else if (promote.matches()) {
        this.oldLeader = promote.group(1);
        newLeader = promote.group(2);
      }

      if (!newLeader.equals("") && newLeader.equals(Minecraft.getMinecraft().thePlayer.getName())) {
        this.transferCountdown = 10;
      }
    }

    final Matcher partyChat = PARTY_PATTERN.matcher(strippedMessage);
    if (partyChat.matches()) {
      final String partyMessage = partyChat.group(2);
      final String user = partyChat.group(1);
      switch (partyMessage) {
        case "!warp":
          Minecraft.getMinecraft().thePlayer.sendChatMessage("/p warp");
          break;
        case "!help":
          Minecraft.getMinecraft().thePlayer.sendChatMessage("Commands: !warp, !m7, !f7, !ptme, !allinv");
          break;
        case "!m7":
          Minecraft.getMinecraft().thePlayer.sendChatMessage("/joindungeon master_catacombs_floor_seven");
          break;
        case "!f7":
          Minecraft.getMinecraft().thePlayer.sendChatMessage("/joindungeon catacombs_floor_seven");
          break;
        case "!allinvite":
        case "!allinv":
          Minecraft.getMinecraft().thePlayer.sendChatMessage("/p settings allinvite");
        case "!ptme":
          event.message.appendSibling(
            new ChatComponentText(" [ACCEPT]")
              .setChatStyle(new ChatStyle()
              .setChatClickEvent(new ClickEvent(ClickEvent.Action.RUN_COMMAND, "/p transfer " + user))
              .setColor(EnumChatFormatting.RED).setBold(true))
          );
          break;
      }
    } else {
      switch (strippedMessage) {
        case "Your Bonzo's Mask saved your life!":
        case "Your ⚚ Bonzo's Mask saved your life!":
          Timer.setInstance(new Timer((byte) 60));
          Minecraft.getMinecraft().thePlayer.sendChatMessage("Bonzo's Mask popped (3s)");
          break;
        case "Second Wind Activated! Your Spirit Mask saved your life!":
        case "Second Wind Activated! Your ⚚ Spirit Mask saved your life!":
          Timer.setInstance(new Timer((byte) 60));
          Minecraft.getMinecraft().thePlayer.sendChatMessage("Spirit Mask popped (3s)");
          break;
        case "Your Phoenix Pet saved you from certain death!":
          Timer.setInstance(new Timer((byte) 60));
          Minecraft.getMinecraft().thePlayer.sendChatMessage("Phoenix pet popped (3s)");
          break;
        default:
          break;
      }
    }
  }

  private void changeColor(final int color) {
    if (this.color < color || this.colorChangeCooldown == 0) {
      this.color = color;
      this.colorChangeCooldown = 10;
      final String title = ChatHandler.COLOR_MAPPING[color-1];
      Minecraft.getMinecraft().ingameGUI.displayTitle(title, "", 0, 5, 1);
    };
  }
}

==> v1.3.0.tar.gz: bonzo-timer_1.8.9/src/main/java/xyz/stachel/bonzotimer/ChatHandler.java <==
package xyz.stachel.bonzotimer;

import net.minecraft.client.Minecraft;
import net.minecraft.event.ClickEvent;
import net.minecraft.util.ChatComponentText;
import net.minecraft.util.ChatStyle;
import net.minecraft.util.EnumChatFormatting;
import net.minecraftforge.client.event.ClientChatReceivedEvent;
import net.minecraftforge.fml.common.eventhandler.SubscribeEvent;
import org.jetbrains.annotations.NotNull;
import net.minecraftforge.fml.common.gameevent.TickEvent;

import java.util.HashMap;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

public class ChatHandler {
  private static final String PLAYER_PATTERN = "(?:\\[(?:VIP\\+?|MVP\\+{0,2}|YOUTUBE|MOD|ADMIN)\\] )?([a-zA-Z0-9_]{2,16})";
  private static final Pattern PARTY_PATTERN = Pattern.compile("Party > " + PLAYER_PATTERN + ": (.*)");
  private static final Pattern TRANSFER_PATTERN = Pattern.compile("The party was transferred to " + PLAYER_PATTERN +" by " + PLAYER_PATTERN);
  private static final Pattern PROMOTE_PATTERN = Pattern.compile(PLAYER_PATTERN + " has promoted " + PLAYER_PATTERN + " to Party Leader");
  private static final Pattern LEAVE_PATTERN = Pattern.compile(PLAYER_PATTERN + " has left the party.");
  //private static final String[] COLOR_MAPPING = { "§6ORANGE", "§aGREEN", "§4RED" ,"§9BLUE", "§5PRPLX" };
  private int transferCountdown = 0;
  private boolean autotransferEnabled = false;
  //private int colorChangeCooldown = 0;
  //private int color = 0;
  private String oldLeader = null;
  private HashMap<String, Byte> rejoiners = new HashMap<>();

  public void setTransferEnabled(boolean b) {
    this.autotransferEnabled = b;
  }

  @SubscribeEvent
  public void onTick(TickEvent.@NotNull ClientTickEvent event) {
    /*if (colorChangeCooldown > 0) {
      colorChangeCooldown--;
    } else {
      color = 0;
    }*/

    if (transferCountdown > 1) {
      transferCountdown--;
    } else if (transferCountdown == 1 && Minecraft.getMinecraft().thePlayer != null && this.oldLeader != null) {
      transferCountdown--;
      Minecraft.getMinecraft().thePlayer.sendChatMessage("/p transfer " + this.oldLeader);
    }

    rejoiners.replaceAll((k, v) -> v > 0 ? (byte)(v - 1) : v);
  }

  @SubscribeEvent
  public void onChatReceived(@NotNull ClientChatReceivedEvent event) {
    if (event.type == 2) return;
      final String strippedMessage = event.message.getUnformattedText().replaceAll("§[0-9a-fklmnor]", "").trim();

    if (autotransferEnabled) {
      final Matcher transfer = TRANSFER_PATTERN.matcher(strippedMessage);
      final Matcher promote = PROMOTE_PATTERN.matcher(strippedMessage);
      String newLeader = "";
      if (transfer.matches()) {
        this.oldLeader = transfer.group(2);
        newLeader = transfer.group(1);
      } else if (promote.matches()) {
        this.oldLeader = promote.group(1);
        newLeader = promote.group(2);
      }

      if (!newLeader.equals("") && newLeader.equals(Minecraft.getMinecraft().thePlayer.getName())) {
        this.transferCountdown = 10;
      }
    }

    final Matcher partyChat = PARTY_PATTERN.matcher(strippedMessage);
    if (partyChat.matches()) {
      final String partyMessage = partyChat.group(2);
      final String user = partyChat.group(1);
      switch (partyMessage) {
        case "!warp":
          Minecraft.getMinecraft().thePlayer.sendChatMessage("/p warp");
          break;
        case "!help":
          Minecraft.getMinecraft().thePlayer.sendChatMessage("Commands: !warp, !m7, !f7, !ptme, !allinv");
          break;
        case "!m7":
          Minecraft.getMinecraft().thePlayer.sendChatMessage("/joindungeon master_catacombs_floor_seven");
          break;
        case "!f7":
          Minecraft.getMinecraft().thePlayer.sendChatMessage("/joindungeon catacombs_floor_seven");
          break;
        case "!allinvite":
        case "!allinv":
          Minecraft.getMinecraft().thePlayer.sendChatMessage("/p settings allinvite");
          break;
        case "!reinv":
          rejoiners.put(user, (byte) 100);
          break;
        case "!ptme":
          event.message.appendSibling(
            new ChatComponentText(" [ACCEPT]")
              .setChatStyle(new ChatStyle()
              .setChatClickEvent(new ClickEvent(ClickEvent.Action.RUN_COMMAND, "/p transfer " + user))
              .setColor(EnumChatFormatting.RED).setBold(true))
          );
          break;
      }
    } else {
      switch (strippedMessage) {
        case "Your Bonzo's Mask saved your life!":
        case "Your ⚚ Bonzo's Mask saved your life!":
          Timer.setInstance(new Timer((byte) 60));
          Minecraft.getMinecraft().thePlayer.sendChatMessage("Bonzo's Mask popped (3s)");
          break;
        case "Second Wind Activated! Your Spirit Mask saved your life!":
        case "Second Wind Activated! Your ⚚ Spirit Mask saved your life!":
          Timer.setInstance(new Timer((byte) 60));
          Minecraft.getMinecraft().thePlayer.sendChatMessage("Spirit Mask popped (3s)");
          break;
        case "Your Phoenix Pet saved you from certain death!":
          Timer.setInstance(new Timer((byte) 60));
          Minecraft.getMinecraft().thePlayer.sendChatMessage("Phoenix pet popped (3s)");
          break;
        default:
          break;
      }

      final Matcher leave = LEAVE_PATTERN.matcher(strippedMessage);
      if (leave.matches()) {
        final String leaver = leave.group(1).trim();
        if (rejoiners.getOrDefault(leaver, (byte) 0) != 0) {
          Minecraft.getMinecraft().thePlayer.sendChatMessage("/party invite " + leaver);
        }
      }
    }
  }

  /* private void changeColor(final int color) {
    if (this.color < color || this.colorChangeCooldown == 0) {
      this.color = color;
      this.colorChangeCooldown = 10;
      final String title = ChatHandler.COLOR_MAPPING[color-1];
      Minecraft.getMinecraft().ingameGUI.displayTitle(title, "", 0, 5, 1);
    };
  }*/
}
